@@ -1,6 +1,6 @@
 "plot.cca" <-
     function (x, choices = c(1, 2), display = c("sp", "wa", "cn"), 
-              scaling = 2, type, ...) 
+              scaling = 2, type, xlim, ylim,  ...) 
 {
     TYPES <- c("text", "points", "none")
     g <- scores(x, choices, display, scaling)
@@ -25,11 +25,13 @@
         else type <- "text"
     }
     else type <- match.arg(type, TYPES)
-    xran <- range(g$spe[, 1], g$sit[, 1], g$con[, 1], g$default[, 
+    if (missing(xlim))
+        xlim <- range(g$spe[, 1], g$sit[, 1], g$con[, 1], g$default[, 
                                                                 1])
-    yran <- range(g$spe[, 2], g$sit[, 2], g$con[, 2], g$default[, 
+    if (missing(ylim))
+        ylim <- range(g$spe[, 2], g$sit[, 2], g$con[, 2], g$default[, 
                                                                 2])
-    plot(g[[1]], xlim = xran, ylim = yran, type = "n", asp = 1, 
+    plot(g[[1]], xlim = xlim, ylim = ylim, type = "n", asp = 1, 
          ...)
     abline(h = 0, lty = 3)
     abline(v = 0, lty = 3)
@@ -55,8 +57,9 @@
     }
     if (!is.null(g$biplot) && type != "none") {
         if (length(display) > 1) {
-            mul <- par("usr")/c(range(g$biplot[, 1]), range(g$biplot[, 2]))
-            mul <- mul[is.finite(mul) & mul>0]
+            mul <- par("usr")/c(range(g$biplot[, 1]), range(g$biplot[, 
+                                                                     2]))
+            mul <- mul[is.finite(mul) & mul > 0]
             mul <- 0.75 * min(mul)
         }
         else mul <- 1
